@@ -1,29 +1,16 @@
-/*  This file is part of the Kate project.
- *
- *  Copyright (C) 2010 Christoph Cullmann <cullmann@kde.org>
- *  Copyright (C) 2010-2018 Dominik Haumann <dhaumann@kde.org>
- *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Library General Public
- *  License as published by the Free Software Foundation; either
- *  version 2 of the License, or (at your option) any later version.
- *
- *  This library is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  Library General Public License for more details.
- *
- *  You should have received a copy of the GNU Library General Public License
- *  along with this library; see the file COPYING.LIB.  If not, write to
- *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- *  Boston, MA 02110-1301, USA.
- */
+/*
+    This file is part of the Kate project.
+    SPDX-FileCopyrightText: 2010 Christoph Cullmann <cullmann@kde.org>
+    SPDX-FileCopyrightText: 2010-2018 Dominik Haumann <dhaumann@kde.org>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
-#include <kateglobal.h>
 #include "katetextbuffertest.h"
 #include "katetextbuffer.h"
 #include "katetextcursor.h"
 #include "katetextfolding.h"
+#include <kateglobal.h>
 
 QTEST_MAIN(KateTextBufferTest)
 
@@ -447,7 +434,8 @@ void KateTextBufferTest::saveFileInUnwritableFolder()
     Kate::TextBuffer buffer(nullptr, 1);
     buffer.setTextCodec(QTextCodec::codecForName("UTF-8"));
     buffer.setFallbackTextCodec(QTextCodec::codecForName("UTF-8"));
-    bool a, b;
+    bool a;
+    bool b;
     int c;
     buffer.load(file_path, a, b, c, true);
     buffer.clear();
@@ -482,7 +470,8 @@ void KateTextBufferTest::saveFileWithElevatedPrivileges()
     Kate::TextBuffer buffer(nullptr, 1, true);
     buffer.setTextCodec(QTextCodec::codecForName("UTF-8"));
     buffer.setFallbackTextCodec(QTextCodec::codecForName("UTF-8"));
-    bool a, b;
+    bool a;
+    bool b;
     int c;
     buffer.load(file_path, a, b, c, true);
     buffer.clear();
