@@ -87,7 +87,7 @@ KateRegExpSearch::ReplacementStream &KateRegExpSearch::ReplacementStream::operat
     case upperCaseFirst:
         if (str.length() > 0) {
             m_str.append(str.at(0).toUpper());
-            m_str.append(str.midRef(1));
+            m_str.append(QStringView(str).mid(1));
             m_caseConversion = keepCase;
         }
         break;
@@ -100,7 +100,7 @@ KateRegExpSearch::ReplacementStream &KateRegExpSearch::ReplacementStream::operat
     case lowerCaseFirst:
         if (str.length() > 0) {
             m_str.append(str.at(0).toLower());
-            m_str.append(str.midRef(1));
+            m_str.append(QStringView(str).mid(1));
             m_caseConversion = keepCase;
         }
         break;
@@ -330,7 +330,7 @@ KateRegExpSearch::search(const QString &pattern, const KTextEditor::Range &input
         int curRelCol = 0;
         int curRelIndex = 0;
 
-        for (TwoViewCursor *twoViewCursor : qAsConst(indicesToCursors)) {
+        for (TwoViewCursor *twoViewCursor : std::as_const(indicesToCursors)) {
             // forward to index, save line/col
             const int index = twoViewCursor->index;
             FAST_DEBUG("resolving position" << index);
@@ -747,6 +747,7 @@ QString KateRegExpSearch::repairPattern(const QString &pattern, bool &stillMulti
     // not as critical
 
     const int inputLen = pattern.length();
+    const QStringView patternView{pattern};
 
     // prepare output
     QString output;
@@ -766,11 +767,11 @@ QString KateRegExpSearch::repairPattern(const QString &pattern, bool &stillMulti
                 case L'x':
                     if (input + 5 < inputLen) {
                         // copy "\x????" unmodified
-                        output.append(pattern.midRef(input, 6));
+                        output.append(patternView.mid(input, 6));
                         input += 6;
                     } else {
                         // copy "\x" unmodified
-                        output.append(pattern.midRef(input, 2));
+                        output.append(patternView.mid(input, 2));
                         input += 2;
                     }
                     stillMultiLine = true;
@@ -779,11 +780,11 @@ QString KateRegExpSearch::repairPattern(const QString &pattern, bool &stillMulti
                 case L'0':
                     if (input + 4 < inputLen) {
                         // copy "\0???" unmodified
-                        output.append(pattern.midRef(input, 5));
+                        output.append(patternView.mid(input, 5));
                         input += 5;
                     } else {
                         // copy "\0" unmodified
-                        output.append(pattern.midRef(input, 2));
+                        output.append(patternView.mid(input, 2));
                         input += 2;
                     }
                     stillMultiLine = true;
@@ -802,7 +803,7 @@ QString KateRegExpSearch::repairPattern(const QString &pattern, bool &stillMulti
 
                 default:
                     // copy "\?" unmodified
-                    output.append(pattern.midRef(input, 2));
+                    output.append(patternView.mid(input, 2));
                     input += 2;
                 }
                 break;
@@ -826,11 +827,11 @@ QString KateRegExpSearch::repairPattern(const QString &pattern, bool &stillMulti
                 case L'x':
                     if (input + 5 < inputLen) {
                         // copy "\x????" unmodified
-                        output.append(pattern.midRef(input, 6));
+                        output.append(patternView.mid(input, 6));
                         input += 6;
                     } else {
                         // copy "\x" unmodified
-                        output.append(pattern.midRef(input, 2));
+                        output.append(patternView.mid(input, 2));
                         input += 2;
                     }
                     stillMultiLine = true;
@@ -839,11 +840,11 @@ QString KateRegExpSearch::repairPattern(const QString &pattern, bool &stillMulti
                 case L'0':
                     if (input + 4 < inputLen) {
                         // copy "\0???" unmodified
-                        output.append(pattern.midRef(input, 5));
+                        output.append(patternView.mid(input, 5));
                         input += 5;
                     } else {
                         // copy "\0" unmodified
-                        output.append(pattern.midRef(input, 2));
+                        output.append(patternView.mid(input, 2));
                         input += 2;
                     }
                     stillMultiLine = true;
@@ -861,7 +862,7 @@ QString KateRegExpSearch::repairPattern(const QString &pattern, bool &stillMulti
                     Q_FALLTHROUGH();
                 default:
                     // copy "\?" unmodified
-                    output.append(pattern.midRef(input, 2));
+                    output.append(patternView.mid(input, 2));
                     input += 2;
                 }
                 break;
