@@ -23,6 +23,7 @@
 #include "inlinenotedata.h"
 #include "inlinenoteinterface.h"
 #include "inlinenoteprovider.h"
+#include "katerenderer.h"
 #include "katevariableexpansionmanager.h"
 #include "markinterface.h"
 #include "modificationinterface.h"
@@ -75,9 +76,7 @@ Editor::Editor(EditorPrivate *impl)
 {
 }
 
-Editor::~Editor()
-{
-}
+Editor::~Editor() = default;
 
 Editor *KTextEditor::Editor::instance()
 {
@@ -128,6 +127,11 @@ void Editor::addVariableExpansion(const QVector<QWidget *> &widgets, const QStri
     d->variableExpansionManager()->showDialog(widgets, variables);
 }
 
+QFont Editor::font() const
+{
+    return d->rendererConfig()->baseFont();
+}
+
 KSyntaxHighlighting::Theme Editor::theme() const
 {
     return KateHlManager::self()->repository().theme(d->rendererConfig()->schema());
@@ -156,8 +160,9 @@ bool View::isStatusBarEnabled() const
 void View::setStatusBarEnabled(bool enable)
 {
     // no state change, do nothing
-    if (enable == !!d->statusBar())
+    if (enable == !!d->statusBar()) {
         return;
+    }
 
     // else toggle it
     d->toggleStatusBar();
@@ -184,9 +189,7 @@ ConfigPage::ConfigPage(QWidget *parent)
 {
 }
 
-ConfigPage::~ConfigPage()
-{
-}
+ConfigPage::~ConfigPage() = default;
 
 QString ConfigPage::fullName() const
 {
@@ -205,9 +208,7 @@ View::View(ViewPrivate *impl, QWidget *parent)
 {
 }
 
-View::~View()
-{
-}
+View::~View() = default;
 
 Plugin::Plugin(QObject *parent)
     : QObject(parent)
@@ -215,9 +216,7 @@ Plugin::Plugin(QObject *parent)
 {
 }
 
-Plugin::~Plugin()
-{
-}
+Plugin::~Plugin() = default;
 
 int Plugin::configPages() const
 {
@@ -229,61 +228,33 @@ ConfigPage *Plugin::configPage(int, QWidget *)
     return nullptr;
 }
 
-MarkInterface::MarkInterface()
-{
-}
+MarkInterface::MarkInterface() = default;
 
-MarkInterface::~MarkInterface()
-{
-}
+MarkInterface::~MarkInterface() = default;
 
-ModificationInterface::ModificationInterface()
-{
-}
+ModificationInterface::ModificationInterface() = default;
 
-ModificationInterface::~ModificationInterface()
-{
-}
+ModificationInterface::~ModificationInterface() = default;
 
-SessionConfigInterface::SessionConfigInterface()
-{
-}
+SessionConfigInterface::SessionConfigInterface() = default;
 
-SessionConfigInterface::~SessionConfigInterface()
-{
-}
+SessionConfigInterface::~SessionConfigInterface() = default;
 
-TextHintInterface::TextHintInterface()
-{
-}
+TextHintInterface::TextHintInterface() = default;
 
-TextHintInterface::~TextHintInterface()
-{
-}
+TextHintInterface::~TextHintInterface() = default;
 
-TextHintProvider::TextHintProvider()
-{
-}
+TextHintProvider::TextHintProvider() = default;
 
-TextHintProvider::~TextHintProvider()
-{
-}
+TextHintProvider::~TextHintProvider() = default;
 
-InlineNoteInterface::InlineNoteInterface()
-{
-}
+InlineNoteInterface::InlineNoteInterface() = default;
 
-InlineNoteInterface::~InlineNoteInterface()
-{
-}
+InlineNoteInterface::~InlineNoteInterface() = default;
 
-InlineNoteProvider::InlineNoteProvider()
-{
-}
+InlineNoteProvider::InlineNoteProvider() = default;
 
-InlineNoteProvider::~InlineNoteProvider()
-{
-}
+InlineNoteProvider::~InlineNoteProvider() = default;
 
 KateInlineNoteData::KateInlineNoteData(KTextEditor::InlineNoteProvider *provider,
                                        const KTextEditor::View *view,
@@ -383,8 +354,9 @@ Command::Command(const QStringList &cmds, QObject *parent)
 Command::~Command()
 {
     // unregister this command, if instance is still there!
-    if (KTextEditor::Editor::instance())
+    if (KTextEditor::Editor::instance()) {
         static_cast<KTextEditor::EditorPrivate *>(KTextEditor::Editor::instance())->cmdManager()->unregisterCommand(this);
+    }
 }
 
 bool Command::supportsRange(const QString &)
