@@ -1,60 +1,58 @@
-/* This file is part of the KDE libraries
-   Copyright (C) 2002 John Firebaugh <jfirebaugh@kde.org>
-   Copyright (C) 2001 Anders Lund <anders@alweb.dk>
-   Copyright (C) 2001 Christoph Cullmann <cullmann@kde.org>
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 2002 John Firebaugh <jfirebaugh@kde.org>
+    SPDX-FileCopyrightText: 2001 Anders Lund <anders@alweb.dk>
+    SPDX-FileCopyrightText: 2001 Christoph Cullmann <cullmann@kde.org>
+    SPDX-FileCopyrightText: 2017-2018 Friedrich W. H. Kossebau <kossebau@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License version 2 as published by the Free Software Foundation.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-only
 */
 
-#ifndef __KATE_VIEW_HELPERS_H__
-#define __KATE_VIEW_HELPERS_H__
+#ifndef KATE_VIEW_HELPERS_H
+#define KATE_VIEW_HELPERS_H
 
-#include <KSelectAction>
-#include <KLineEdit>
 #include <KActionMenu>
+#include <KLineEdit>
+#include <KSelectAction>
 
+#include <QColor>
+#include <QHash>
+#include <QLayout>
+#include <QMap>
 #include <QPixmap>
 #include <QPointer>
-#include <QColor>
 #include <QScrollBar>
-#include <QHash>
 #include <QStackedWidget>
-#include <QMap>
-#include <QTimer>
 #include <QTextLayout>
-#include <QLayout>
+#include <QTimer>
 
-#include <ktexteditor/message.h>
-#include <ktexteditor/cursor.h>
-#include <ktexteditor_export.h>
 #include "katetextline.h"
+#include <ktexteditor/cursor.h>
+#include <ktexteditor/message.h>
+#include <ktexteditor_export.h>
+
+namespace KTextEditor
+{
+class ViewPrivate;
+class DocumentPrivate;
+class Command;
+class AnnotationModel;
+class MovingRange;
+class AbstractAnnotationItemDelegate;
+class StyleOptionAnnotationItem;
+}
 
-namespace KTextEditor { class DocumentPrivate; }
-namespace KTextEditor { class ViewPrivate; }
 class KateViewInternal;
+class KateTextLayout;
 
 #define MAXFOLDINGCOLORS 16
 
 class KateLineInfo;
 class KateTextPreview;
 
-namespace KTextEditor
+namespace Kate
 {
-class Command;
-class AnnotationModel;
-class MovingRange;
+class TextRange;
 }
 
 class QTimer;
@@ -68,33 +66,34 @@ class QVBoxLayout;
 class KateMessageLayout : public QLayout
 {
 public:
-    explicit KateMessageLayout (QWidget *parent);
-    ~KateMessageLayout();
+    explicit KateMessageLayout(QWidget *parent);
+    ~KateMessageLayout() override;
 
     void addWidget(QWidget *widget, KTextEditor::Message::MessagePosition pos);
-    int count() const Q_DECL_OVERRIDE;
-    QLayoutItem *itemAt(int index) const Q_DECL_OVERRIDE;
-    void setGeometry(const QRect &rect) Q_DECL_OVERRIDE;
-    QSize sizeHint() const Q_DECL_OVERRIDE;
-    QLayoutItem *takeAt(int index) Q_DECL_OVERRIDE;
+    int count() const override;
+    QLayoutItem *itemAt(int index) const override;
+    void setGeometry(const QRect &rect) override;
+    QSize sizeHint() const override;
+    QLayoutItem *takeAt(int index) override;
 
     void add(QLayoutItem *item, KTextEditor::Message::MessagePosition pos);
 
 private:
-    void addItem(QLayoutItem *item) Q_DECL_OVERRIDE; // never called publically
+    void addItem(QLayoutItem *item) override; // never called publically
 
-    struct ItemWrapper
-    {
+    struct ItemWrapper {
+        ItemWrapper() = default;
         ItemWrapper(QLayoutItem *i, KTextEditor::Message::MessagePosition pos)
             : item(i)
             , position(pos)
-        {}
+        {
+        }
 
-        QLayoutItem * item = nullptr;
-        KTextEditor::Message::MessagePosition position;
+        QLayoutItem *item = nullptr;
+        KTextEditor::Message::MessagePosition position = KTextEditor::Message::AboveView;
     };
 
-    QVector<ItemWrapper *> m_items;
+    QVector<ItemWrapper> m_items;
 };
 
 /**
@@ -110,8 +109,10 @@ class KateScrollBar : public QScrollBar
 
 public:
     KateScrollBar(Qt::Orientation orientation, class KateViewInternal *parent);
-    virtual ~KateScrollBar();
-    QSize sizeHint() const Q_DECL_OVERRIDE;
+    ~KateScrollBar() override;
+    QSize sizeHint() const override;
+
+    void showEvent(QShowEvent *event) override;
 
     inline bool showMarks() const
     {
@@ -160,14 +161,14 @@ Q_SIGNALS:
     void sliderMMBMoved(int value);
 
 protected:
-    void mousePressEvent(QMouseEvent *e) Q_DECL_OVERRIDE;
-    void mouseReleaseEvent(QMouseEvent *e) Q_DECL_OVERRIDE;
-    void mouseMoveEvent(QMouseEvent *e) Q_DECL_OVERRIDE;
-    void leaveEvent(QEvent *event) Q_DECL_OVERRIDE;
-    bool eventFilter(QObject *object, QEvent *event) Q_DECL_OVERRIDE;
-    void paintEvent(QPaintEvent *e) Q_DECL_OVERRIDE;
-    void resizeEvent(QResizeEvent *) Q_DECL_OVERRIDE;
-    void sliderChange(SliderChange change) Q_DECL_OVERRIDE;
+    void mousePressEvent(QMouseEvent *e) override;
+    void mouseReleaseEvent(QMouseEvent *e) override;
+    void mouseMoveEvent(QMouseEvent *e) override;
+    void leaveEvent(QEvent *event) override;
+    bool eventFilter(QObject *object, QEvent *event) override;
+    void paintEvent(QPaintEvent *e) override;
+    void resizeEvent(QResizeEvent *) override;
+    void sliderChange(SliderChange change) override;
 
 protected Q_SLOTS:
     void sliderMaybeMoved(int value);
@@ -178,6 +179,7 @@ public Q_SLOTS:
 
 private Q_SLOTS:
     void showTextPreview();
+
 private:
     void showTextPreviewDelayed();
     void hideTextPreview();
@@ -190,9 +192,14 @@ private:
 
     int minimapYToStdY(int y);
 
-    const QColor charColor(const QVector<Kate::TextLineData::Attribute> &attributes, int &attributeIndex,
-                           const QList<QTextLayout::FormatRange> &decorations,
-                           const QColor &defaultColor, int x, QChar ch);
+    using ColumnRangeWithColor = std::pair<QPen, std::pair<int, int>>;
+    ColumnRangeWithColor charColor(const QVector<Kate::TextLineData::Attribute> &attributes,
+                                   int &attributeIndex,
+                                   const QVector<Kate::TextRange *> &decorations,
+                                   const QBrush &defaultColor,
+                                   int x,
+                                   QChar ch,
+                                   QHash<QRgb, QPen> &penCache);
 
     bool m_middleMouseDown;
     bool m_leftMouseDown;
@@ -208,13 +215,14 @@ private:
     bool m_showMarks;
     bool m_showMiniMap;
     bool m_miniMapAll;
+    bool m_needsUpdateOnShow;
     int m_miniMapWidth;
 
     QPixmap m_pixmap;
-    int     m_grooveHeight;
-    QRect   m_stdGroveRect;
-    QRect   m_mapGroveRect;
-    QTimer  m_updateTimer;
+    int m_grooveHeight;
+    QRect m_stdGroveRect;
+    QRect m_mapGroveRect;
+    QTimer m_updateTimer;
     QPoint m_toolTipPos;
 
     // lists of lines added/removed recently to avoid scrollbar flickering
@@ -230,9 +238,9 @@ class KateIconBorder : public QWidget
 
 public:
     KateIconBorder(KateViewInternal *internalView, QWidget *parent);
-    virtual ~KateIconBorder();
+    ~KateIconBorder() override;
     // VERY IMPORTANT ;)
-    QSize sizeHint() const Q_DECL_OVERRIDE;
+    QSize sizeHint() const override;
 
     void updateFont();
     int lineNumberWidth() const;
@@ -242,7 +250,7 @@ public:
     void setRelLineNumbersOn(bool enable);
     void setAnnotationBorderOn(bool enable);
     void setDynWrapIndicators(int state);
-    int dynWrapIndicators()  const
+    int dynWrapIndicators() const
     {
         return m_dynWrapIndicators;
     }
@@ -263,19 +271,19 @@ public:
     {
         setFoldingMarkersOn(!foldingMarkersOn());
     }
-    inline bool iconBorderOn()       const
+    inline bool iconBorderOn() const
     {
         return m_iconBorderOn;
     }
-    inline bool lineNumbersOn()      const
+    inline bool lineNumbersOn() const
     {
         return m_lineNumbersOn;
     }
-    inline bool viRelNumbersOn()     const
+    inline bool viRelNumbersOn() const
     {
         return m_relLineNumbersOn;
     }
-    inline bool foldingMarkersOn()   const
+    inline bool foldingMarkersOn() const
     {
         return m_foldingMarkersOn;
     }
@@ -289,6 +297,17 @@ public:
     enum BorderArea { None, LineNumbers, IconBorder, FoldingMarkers, AnnotationBorder, ModificationBorder };
     BorderArea positionToArea(const QPoint &) const;
 
+    KTextEditor::AbstractAnnotationItemDelegate *annotationItemDelegate() const;
+    void setAnnotationItemDelegate(KTextEditor::AbstractAnnotationItemDelegate *delegate);
+    inline bool uniformAnnotationItemSizes() const
+    {
+        return m_hasUniformAnnotationItemSizes;
+    }
+    inline void setAnnotationUniformItemSizes(bool enable)
+    {
+        m_hasUniformAnnotationItemSizes = enable;
+    }
+
 public Q_SLOTS:
     void updateAnnotationBorderWidth();
     void updateAnnotationLine(int line);
@@ -296,66 +315,82 @@ public Q_SLOTS:
     void displayRangeChanged();
 
 private:
-    void paintEvent(QPaintEvent *) Q_DECL_OVERRIDE;
+    void dragEnterEvent(QDragEnterEvent *) override;
+    void dragMoveEvent(QDragMoveEvent *event) override;
+    void dropEvent(QDropEvent *event) override;
+    void paintEvent(QPaintEvent *) override;
     void paintBorder(int x, int y, int width, int height);
 
-    void mousePressEvent(QMouseEvent *) Q_DECL_OVERRIDE;
-    void mouseMoveEvent(QMouseEvent *) Q_DECL_OVERRIDE;
-    void mouseReleaseEvent(QMouseEvent *) Q_DECL_OVERRIDE;
-    void mouseDoubleClickEvent(QMouseEvent *) Q_DECL_OVERRIDE;
-    void leaveEvent(QEvent *event) Q_DECL_OVERRIDE;
-    void wheelEvent(QWheelEvent *e) Q_DECL_OVERRIDE;
+    void mousePressEvent(QMouseEvent *) override;
+    void mouseMoveEvent(QMouseEvent *) override;
+    void mouseReleaseEvent(QMouseEvent *) override;
+    void mouseDoubleClickEvent(QMouseEvent *) override;
+    void leaveEvent(QEvent *event) override;
+    void wheelEvent(QWheelEvent *e) override;
 
     void showMarkMenu(uint line, const QPoint &pos);
 
-    void showAnnotationTooltip(int line, const QPoint &pos);
     void hideAnnotationTooltip();
     void removeAnnotationHovering();
     void showAnnotationMenu(int line, const QPoint &pos);
-    int annotationLineWidth(int line);
+    void calcAnnotationBorderWidth();
 
+    void initStyleOption(KTextEditor::StyleOptionAnnotationItem *styleOption) const;
+    void setStyleOptionLineData(KTextEditor::StyleOptionAnnotationItem *styleOption,
+                                int y,
+                                int realLine,
+                                const KTextEditor::AnnotationModel *model,
+                                const QString &annotationGroupIdentifier) const;
+    QRect annotationLineRectInView(int line) const;
+
+private:
     KTextEditor::ViewPrivate *m_view;
     KTextEditor::DocumentPrivate *m_doc;
     KateViewInternal *m_viewInternal;
 
-    bool m_iconBorderOn: 1;
-    bool m_lineNumbersOn: 1;
-    bool m_relLineNumbersOn:1;
-    bool m_updateRelLineNumbers:1;
-    bool m_foldingMarkersOn: 1;
-    bool m_dynWrapIndicatorsOn: 1;
-    bool m_annotationBorderOn: 1;
-    int m_dynWrapIndicators;
+    bool m_iconBorderOn : 1;
+    bool m_lineNumbersOn : 1;
+    bool m_relLineNumbersOn : 1;
+    bool m_updateRelLineNumbers : 1;
+    bool m_foldingMarkersOn : 1;
+    bool m_dynWrapIndicatorsOn : 1;
+    bool m_annotationBorderOn : 1;
+    bool m_updatePositionToArea : 1;
 
-    int m_lastClickedLine;
+    typedef QPair<int, KateIconBorder::BorderArea> AreaPosition;
+    std::vector<AreaPosition> m_positionToArea;
 
-    int m_cachedLNWidth;
+    const int m_separatorWidth = 2;
+    const int m_modAreaWidth = 3;
+    qreal m_maxCharWidth = 0.0;
+    int m_lineNumberAreaWidth = 0;
+    int m_iconAreaWidth = 0;
+    int m_foldingAreaWidth = 0;
+    int m_annotationAreaWidth = 0;
+    const QChar m_dynWrapIndicatorChar = QChar(0x21AA);
+    int m_dynWrapIndicators = 0;
+    int m_lastClickedLine = -1;
 
-    qreal m_maxCharWidth;
-    int iconPaneWidth;
-    int m_annotationBorderWidth;
-
-    mutable QPixmap m_arrow;
-    mutable QColor m_oldBackgroundColor;
+    KTextEditor::AbstractAnnotationItemDelegate *m_annotationItemDelegate;
+    bool m_hasUniformAnnotationItemSizes = false;
+    bool m_isDefaultAnnotationItemDelegate = true;
 
     QPointer<KateTextPreview> m_foldingPreview;
-    KTextEditor::MovingRange *m_foldingRange;
-    int m_nextHighlightBlock;
-    int m_currentBlockLine;
-    QTimer m_delayFoldingHlTimer;
-    void showDelayedBlock(int line);
-    void hideBlock();
+    KTextEditor::MovingRange *m_foldingRange = nullptr;
+    int m_currentLine = -1;
+    QTimer m_antiFlickerTimer;
+    void highlightFoldingDelayed(int line);
+    void hideFolding();
 
 private Q_SLOTS:
-    void showBlock();
+    void highlightFolding();
+    void handleDestroyedAnnotationItemDelegate();
 
 private:
     QString m_hoveredAnnotationGroupIdentifier;
-
-    void initializeFoldingColors();
 };
 
-class KateViewEncodingAction: public KSelectAction
+class KateViewEncodingAction : public KSelectAction
 {
     Q_OBJECT
 
@@ -365,8 +400,6 @@ class KateViewEncodingAction: public KSelectAction
 public:
     KateViewEncodingAction(KTextEditor::DocumentPrivate *_doc, KTextEditor::ViewPrivate *_view, const QString &text, QObject *parent, bool saveAsMode = false);
 
-    ~KateViewEncodingAction();
-
     int mibForName(const QString &codecName, bool *ok = nullptr) const;
     QTextCodec *codecForMib(int mib) const;
 
@@ -381,9 +414,9 @@ public:
 
 Q_SIGNALS:
     /**
-    * Specific (proper) codec was selected
-    */
-    void triggered(QTextCodec *codec);
+     * Specific (proper) codec was selected
+     */
+    void codecSelected(QTextCodec *codec);
 
 private:
     KTextEditor::DocumentPrivate *doc;
@@ -392,9 +425,9 @@ private:
     class Private
     {
     public:
-        Private(KateViewEncodingAction *parent)
-            : q(parent),
-              currentSubAction(nullptr)
+        explicit Private(KateViewEncodingAction *parent)
+            : q(parent)
+            , currentSubAction(nullptr)
         {
         }
 
@@ -406,7 +439,7 @@ private:
         QAction *currentSubAction;
     };
 
-    Private *const d;
+    std::unique_ptr<Private> const d;
     Q_PRIVATE_SLOT(d, void _k_subActionTriggered(QAction *))
 
     const bool m_saveAsMode;
@@ -426,7 +459,9 @@ class KateViewBarWidget : public QWidget
 public:
     explicit KateViewBarWidget(bool addCloseButton, QWidget *parent = nullptr);
 
-    virtual void closed() {}
+    virtual void closed()
+    {
+    }
 
     /// returns the currently associated KateViewBar and 0, if it is not associated
     KateViewBar *viewBar()
@@ -443,6 +478,14 @@ protected:
         return m_centralWidget;
     }
 
+    /**
+     * @return close button, if there
+     */
+    QToolButton *closeButton()
+    {
+        return m_closeButton;
+    }
+
 Q_SIGNALS:
     void hideMe();
 
@@ -454,8 +497,9 @@ private:
     }
 
 private:
-    QWidget *m_centralWidget;
-    KateViewBar *m_viewBar; // 0-pointer, if not added to a view bar
+    QWidget *m_centralWidget = nullptr;
+    KateViewBar *m_viewBar = nullptr; // 0-pointer, if not added to a view bar
+    QToolButton *m_closeButton = nullptr;
 };
 
 class KateViewBar : public QWidget
@@ -463,9 +507,7 @@ class KateViewBar : public QWidget
     Q_OBJECT
 
 public:
-    KateViewBar(bool external,
-                QWidget *parent,
-                KTextEditor::ViewPrivate *view);
+    KateViewBar(bool external, QWidget *parent, KTextEditor::ViewPrivate *view);
 
     /**
      * Adds a widget to this viewbar.
@@ -529,8 +571,8 @@ public Q_SLOTS:
     void hideCurrentBarWidget();
 
 protected:
-    void keyPressEvent(QKeyEvent *event) Q_DECL_OVERRIDE;
-    void hideEvent(QHideEvent *event) Q_DECL_OVERRIDE;
+    void keyPressEvent(QKeyEvent *event) override;
+    void hideEvent(QHideEvent *event) override;
 
 private:
     /**
@@ -571,9 +613,9 @@ class KateCmdLineEdit : public KLineEdit
 
 public:
     KateCmdLineEdit(KateCommandLineBar *bar, KTextEditor::ViewPrivate *view);
-    bool event(QEvent *e) Q_DECL_OVERRIDE;
+    bool event(QEvent *e) override;
 
-    void hideEvent(QHideEvent *e) Q_DECL_OVERRIDE;
+    void hideEvent(QHideEvent *e) override;
 
 Q_SIGNALS:
     void hideRequested();
@@ -585,8 +627,8 @@ private Q_SLOTS:
     void hideLineEdit();
 
 protected:
-    void focusInEvent(QFocusEvent *ev) Q_DECL_OVERRIDE;
-    void keyPressEvent(QKeyEvent *ev) Q_DECL_OVERRIDE;
+    void focusInEvent(QFocusEvent *ev) override;
+    void keyPressEvent(QKeyEvent *ev) override;
 
 private:
     /**
@@ -599,7 +641,6 @@ private:
      * @param string the expression to parse
      * @return the position, an integer
      */
-    int calculatePosition(QString string);
     void fromHistory(bool up);
     QString helptext(const QPoint &) const;
 
@@ -630,5 +671,33 @@ private Q_SLOTS:
     void paste();
 };
 
-#endif
+class KateViewSchemaAction : public KActionMenu
+{
+    Q_OBJECT
 
+public:
+    KateViewSchemaAction(const QString &text, QObject *parent)
+        : KActionMenu(text, parent)
+    {
+        init();
+        setPopupMode(QToolButton::InstantPopup);
+    }
+
+    void updateMenu(KTextEditor::ViewPrivate *view);
+
+private:
+    void init();
+
+    QPointer<KTextEditor::ViewPrivate> m_view;
+    QStringList names;
+    QActionGroup *m_group;
+    int last;
+
+public Q_SLOTS:
+    void slotAboutToShow();
+
+private Q_SLOTS:
+    void setSchema();
+};
+
+#endif
